@@ -1,8 +1,6 @@
 #ifndef PHALANX_CONFIG_HPP
 #define PHALANX_CONFIG_HPP
 
-#define HAVE_MPI
-
 /* #undef PHX_DEBUG */
 
 #define PHX_TEUCHOS_TIME_MONITOR
@@ -11,18 +9,18 @@
 
 /* #undef PHX_ETI */
 
-/* #undef PHX_KOKKOS_DEVICE_TYPE_SERIAL */
+#define PHX_KOKKOS_DEVICE_TYPE_SERIAL
 /* #undef PHX_KOKKOS_DEVICE_TYPE_CUDA */
 /* #undef PHX_KOKKOS_DEVICE_TYPE_THREAD */
-#define PHX_KOKKOS_DEVICE_TYPE_OPENMP
+/* #undef PHX_KOKKOS_DEVICE_TYPE_OPENMP */
 
 /* #undef PHX_INDEX_SIZE_TYPE_KOKKOS */
-/* #undef PHX_INDEX_SIZE_TYPE_INT */
-#define PHX_INDEX_SIZE_TYPE_UINT
+#define PHX_INDEX_SIZE_TYPE_INT
+/* #undef PHX_INDEX_SIZE_TYPE_UINT */
 /* #undef PHX_INDEX_SIZE_TYPE_LONGINT */
 /* #undef PHX_INDEX_SIZE_TYPE_ULONGINT */
 
-/* #undef Phalanx_ENABLE_Intrepid2 */
+/* #undef PHX_ENABLE_KOKKOS_AMT */
 
 #ifndef PHALANX_DEPRECATED
 #  if (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 1))
