@@ -1,5 +1,5 @@
 /* Define if want to build teuchos-complex */
-#define HAVE_SACADO_COMPLEX
+/* #undef HAVE_SACADO_COMPLEX */
 
 /* Define if want to build with uninit */
 /* #undef HAVE_SACADO_UNINIT */
@@ -25,6 +25,9 @@
 /* Define if want to build with kokkos-core enabled */
 #define HAVE_SACADO_KOKKOSCORE
 
+/* Define if want to build with kokkos-containers enabled */
+#define HAVE_SACADO_KOKKOSCONTAINERS
+
 /* Define if want to build with TeuchosKokkosComm subpackage enabled */
 #define HAVE_SACADO_TEUCHOSKOKKOSCOMM
 #ifdef HAVE_SACADO_TEUCHOSKOKKOSCOMM
@@ -47,3 +50,21 @@
 
 /* Define to enable C++11 support*/
 #define HAVE_SACADO_CXX11
+
+/* Define to enable hierarchical parallelism support */
+#if !defined(SACADO_VIEW_CUDA_HIERARCHICAL) && !defined(SACADO_VIEW_CUDA_HIERARCHICAL_DFAD)
+/* #undef SACADO_VIEW_CUDA_HIERARCHICAL */
+#endif
+
+/* Define to enable hierarchical parallelism support specific to DFad */
+#if !defined(SACADO_VIEW_CUDA_HIERARCHICAL) && !defined(SACADO_VIEW_CUDA_HIERARCHICAL_DFAD)
+/* #undef SACADO_VIEW_CUDA_HIERARCHICAL_DFAD */
+#endif
+
+/* Define to enable Kokkos memory pool in Sacado */
+#ifndef SACADO_KOKKOS_USE_MEMORY_POOL
+/* #undef SACADO_KOKKOS_USE_MEMORY_POOL */
+#endif
+
+/* Define if want to make the new Fad design the default, replacing the old one */
+/* #undef SACADO_NEW_FAD_DESIGN_IS_DEFAULT */
