@@ -7,9 +7,9 @@
 
 /* #undef HAVE_THYRA_TEUCHOS_BLASFLOAT */
 
-#define HAVE_THYRA_FLOAT
+/* #undef HAVE_THYRA_FLOAT */
 
-#define HAVE_THYRA_COMPLEX
+/* #undef HAVE_THYRA_COMPLEX */
 
 /* #undef HAVE_THYRA_DEBUG */
 
