@@ -2,7 +2,7 @@
 #define TPETRATSQR_CONFIG_H
 
 /* Define if building TSQR with std::complex<T> support */
-#define HAVE_KOKKOSTSQR_COMPLEX
+/* #undef HAVE_KOKKOSTSQR_COMPLEX */
 
 /* Define if the TBB (Intel Threading Building Blocks) TPL is available */
 /* #undef HAVE_KOKKOSTSQR_TBB */
