@@ -7,6 +7,10 @@
 
 #define HAVE_XPETRA_EPETRA
 
+#define HAVE_XPETRA_KOKKOSCORE
+
+#define HAVE_XPETRA_KOKKOSCONTAINERS
+
 /* #undef HAVE_XPETRA_KOKKOS_REFACTOR */
 
 /* #undef HAVE_XPETRA_KOKKOSCLASSIC */
@@ -23,10 +27,4 @@
 
 /* #undef XPETRA_EPETRA_NO_64BIT_GLOBAL_INDICES */
 
-/* Flags for active Tpetra nodes if Tpetra is enabled */
-#define HAVE_XPETRA_SERIAL
-/* #undef HAVE_XPETRA_PTHREAD */
-#define HAVE_XPETRA_OPENMP
-/* #undef HAVE_XPETRA_CUDA */
-
 #endif // XPETRA_CONFIG_HPP
