@@ -52,6 +52,7 @@ PyTrilinos: A python interface to selected Trilinos packages.  This installation
     Epetra
     TriUtils
     Tpetra
+    Domi
     EpetraExt
     Isorropia
     Pliris
@@ -99,6 +100,7 @@ __all__ = ['Teuchos',
           'Epetra',
           'TriUtils',
           'Tpetra',
+          'Domi',
           'EpetraExt',
           'Isorropia',
           'Pliris',
@@ -115,16 +117,16 @@ __all__ = ['Teuchos',
 
 # Versioning.  Set the __version__ special variable and define a version()
 # function.
-__version__ = '12.3;(;Dev;)'
+__version__ = '12.12'
 def version():
-    return 'Trilinos version: 12.6.3\nPyTrilinos version: ' + __version__
+    return 'Trilinos version: 12.12.1\nPyTrilinos version: ' + __version__
 
 #
 # Import utility class
-from PropertyBase import PropertyBase
+from .PropertyBase import PropertyBase
 #
 # Import the typed tuple factory and classes
-from typed_tuple import *
+from .typed_tuple import *
 #
 # Import the typed dict factory
-from typed_dict import *
+from .typed_dict import *
